%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% instruction_calculation.m (Matlab script)
%% 
%% Solves the ballistique equation system
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [lon_targeted,lat_targeted,distance,cape,boat_speed,duration_to_follow,u_boat,v_boat]...
    = instruction_calculation(longitude_boat_new,latitude_boat_new,lonspir_pttargeted,latspir_pttargeted,...
    u_current,v_current,xboat_new,yboat_new,boat_speed,quality)
%
% Calculating navigation instructions to join the next Spirale point
% 
%
% Operating principle
%
% Input
% calcul_consignes 
% (   x0,y0
%    ,xbouee_new, ybouee_new,tbouee_new
%    ,xbouee_old,ybouee_old, tbouee_old,
%    ,xbateau_new,ybateau_new,
%    ,vitesse_bateau,
%    qualite)
%
% Output
% current velocity calculated (module and direction)
% coordinates of the target point and distance
% boat heading to get to the target point
%
% Calculating time needed for the buoy and the boat to be on the same point
% - knowing boat speed
%
% Calculation of the current (u et v)= distance/time
%
% Resolution equations system where t is the time sought
% module of vitesse_bateau is fixed
%
% xboat_new+u_boat*t = x0+u_current*t
% yboat_new+v_boat*t = y0+v_current*t
% (u_boat^2+v_boat^2)= vitesse_bateau^2
%
% a*t^2+b*t+c=0
%

[s,a12,a21] = m_idist(longitude_boat_new,latitude_boat_new,lonspir_pttargeted,latspir_pttargeted);
theta=(90-a12)*pi/180;
[dx,dy]=pol2cart(theta,s); %m

a=u_current^2+v_current^2-boat_speed^2;
b=2*dx*u_current+2*dy*v_current;
c=dx^2+dy^2;

delta=b^2-4*a*c;

if delta>=0
    
    solution1=(-b-sqrt(delta))/(2*a);
    solution2=(-b+sqrt(delta))/(2*a);
    duration_to_follow=max(solution1,solution2);
        
    u_boat=(dx/duration_to_follow)+u_current;
    v_boat=(dy/duration_to_follow)+v_current;
    
    cape=uv_2_direction(u_boat,v_boat);    
    v_boat_calcule=sqrt(u_boat^2+v_boat^2);
    distance=v_boat_calcule*duration_to_follow;

    save memo_instructions cape v_boat_calcule 

    [lon_targeted,lat_targeted]=m_fdist(longitude_boat_new,latitude_boat_new,cape,distance);
    
else
    waitfor(msgbox('The discriminant of the ballistic equation system is negative. A real solution does not exist.'));
    lon_targeted=9999
    lat_targeted=9999
    distance=9999
    cape=9999
    duration_to_follow=9999
    u_boat=9999
    v_boat=9999
    return
end

