%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% lagrangian_navigation_demo.m (Matlab script)
%% 
%% Routine to plot vessel route in both geographical and 
%% Lagrangian reference frames
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%% Credits: L.Rousselet.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%distance calculation between vessel and buoy
[ss,a12,a21]  = m_idist(BuoyLonMemo,BuoyLatMemo,VesselLonMemo,VesselLatMemo);
theta         = (90.-a12)*pi/180.;
[distx,disty] = pol2cart(theta,ss);%[m]
distx         = distx./1000.; %[km]
disty         = disty./1000.; %[km]


figure(3);hold on;
set(gcf,'position',[Hoffset ScreenHeigth/2-Voffset ScreenWidth/2  ScreenHeigth/2]);
%- Plot coast -%
hold on;
UserCoast='GOL.mat';
m_usercoast(UserCoast,'patch',[.7 .7 .7])
m_quiver(lon,lat,u_rho,v_rho,10,'color','k')

%- Plot Vessel path -%
hold on;
m_line(VesselLonMemo,VesselLatMemo,'color','b','LineWidth',4);
% m_plot(VesselLon,VesselLat,'.b');

%- Plot Iridium buoy positions -%
hold on;
m_line(BuoyLonMemo,BuoyLatMemo,'color','g','LineWidth',4);
m_plot(BuoyLonMemo,BuoyLatMemo,'.g','MarkerSize',8);

m_grid('box','fancy');
%title({IridiumDir(10:end);'Vessel (blue) - Buoy (green) tracks'})
title('Vessel (blue) - Buoy (green) tracks')
xlabel('longitude');
ylabel('latitude');


figure(4);hold on;
set(gcf,'position',[ScreenWidth/2+Hoffset ScreenHeigth/2-Voffset ScreenWidth/2  ScreenHeigth/2]);

plot(xx,yy,'-r')

plot(distx,disty,'-b','LineWidth',4)

axis('square');
axis([min(xx)-1 max(xx)+1 min(yy)-1 max(yy)+1])

title('expected (red) and obtained (blue) vessel track in the Lagrangian reference frame')
xlabel('Distance [km]');
ylabel('Distance [km]');
set(gca,'Linewidth',2)
grid on
box on

% Calculation of distance made by the boat and theoretical spirale distance

% Spirale
cumulative_distance=totdist/1000; %[km]

% Boat
size_VesselLonMemo=size(VesselLonMemo);
cumulative_distance_vessel=0;
for i=1:size_VesselLonMemo(2)-1;
   cumulative_distance_vessel=cumulative_distance_vessel+m_lldist(VesselLonMemo(i:i+1),VesselLatMemo(i:i+1));
end

if target_number==size_lonspir(2)
	% Lagrangian navigation score : 100% = boat follow exactly the spiral. 
	% The greater the cumulative distance  of the boat,the lower the score.
	score=100-abs(cumulative_distance-cumulative_distance_vessel)/cumulative_distance*100;
	waitfor(msgbox(['Your score is ', num2str(score,'%2.2f' ),'%'], 'Score' ));

	figure(4)
	text(max(xx)+1,1,'  Score','FontSize',20)
	text(max(xx)+1,0,['  ',num2str(score,'%2.2f'),'%'],'FontSize',20) 
else
	waitfor(msgbox(['I can not calculate your score since you do not navigate until the last spiral point'], 'Score' ));
end	

saveas(3,[figdir,'lagrangian_navigation_demo_lonlat.png']) 

saveas(4,[figdir,'lagrangian_navigation_demo_lagframe.png']) 

break

