%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% lagrangian_release_test.m (Matlab script)
%%
%% script for comparison between a tracer release of an instantaneuous 
%% quadratic patch and along a Lagrangia square spirale route
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Files needed :
%% - lagrangian_release_test_quadraticpatch.m
%% - lagrangian_release_test_sprialrelease.m
%%
%% Output:
%% - figures of tracer release and SF6 concentration
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli, F.Nencioli, M.Kersale
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help lagrangian_release_test
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
LATEXtools_param
%
%
durationDAYS=1 %[days]
xdistanceKM=100 %[km]
ydistanceKM=100 %[km]

timefiguresDAYS=durationDAYS; %[days]

dt=100; %[s]
dx=1000;%[m]
dy=1000;%[m]
dz=20;%[m] equal to estimated mixing layer depth

flux=100; % nb of particles released at each timestep

shipvel=3;   %ship speed [knots];
container=7000; %[l]
fluxSF6min=9;   %SF6 flux [l/min];
conc_sat=1.77*10^-4; % tracer saturation concentration [mol/l]

%- Square spirale route parameters
step_x = 600; %[m]
step_y = 600; %[m]
way='in_out'; % the spiral route is performed from its center to outside
%way='out_in';  % the spiral route is performed from outside to its center
fig_spir='y'; % animation plot of release 'y' or 'n'
it_fig_spir=5;

kh=2.5;%horizontal diffusion coefficient [m²/s] Nencioli et al 2013 =>2.5

vfield='eddy'; %type of velocityt field: 'unifor', 'shea' or 'eddy'
vmax=0.1;%[m/s]

detectiontreshold='y';
dec_treshold=10*1.e-17;%[mol/l]
%prefix=1e-9; 
%prefix_str='nano'

prefix=1e-15; 
prefix_str='femto'


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% END user defined parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%conversions
duration=durationDAYS*86400; %[s]
xdistance=xdistanceKM*1000;%[m]
ydistance=ydistanceKM*1000;%[m]

%itmax=20000;
itmax=fix(duration/dt) % number of timestep
%imax=1000;
imax=fix(xdistance/dx) 
%jmax=1000;
jmax=fix(ydistance/dy)

%concentration figures
timefigures=timefiguresDAYS*86400; %[s]
deltatime=fix(timefigures/dt); %[s]


%%buoy initial position at the center of the domain
xbuoy=fix(imax/2)*dx;
ybuoy=fix(jmax/2)*dy;
%%% center of quadratic patch
xc=xbuoy;
yc=ybuoy;


vel=shipvel*1.852*1000/3600; % vessel speed in [m/s]


fluxSF6=fluxSF6min/60;   %SF6 flux [l/s];

sigma=sqrt(2*kh*dt); % standard deviation of gaussian pdf [m]

%%% calculation of the numebr of coil of the spiral
distanceSF6=vel/fluxSF6*container;
coil_number=0;
totdist=0;
while totdist <= distanceSF6-0.1*distanceSF6
    coil_number=coil_number+1;
    [coord_spiral,totdist]=spiral_calculation(coil_number,step_x,step_y);    
end
%coil_number
%totdist
%disp('pause...');pause
%break

%%grid making
i=[1:1:imax];
j=[1:1:jmax];
[x,y]=meshgrid(i,j);
x=x*dx;
y=y*dy;

%%% current field %[m/s]
%%%UNIFORM
if vfield=='unif'
    u(j,i)=vmax; 
    v(j,i)=0.0;
elseif vfield=='shea';
for i=1:imax
    for j=1:jmax
    u(j,i)=0.001*j;%[m^2s^-1]
    v(j,i)=0;
    end
end  
else vfield=='eddy';
%%% EDDY
xc_eddy_ini=xc-5000;
yc_eddy_ini=yc;
sigma_eddy=10000000;
psimax=1000;
vel_eddy=0.05; %[m/s] not null for a moving eddy
%
xc_eddy=xc_eddy_ini;
yc_eddy=yc_eddy_ini;
psi = psimax*exp(-(((x-xc_eddy).^2)/2/sigma_eddy + ((y-yc_eddy).^2)/2/sigma_eddy));
u(j,i)=0;
v(j,i)=0.0;
for i=1:imax-1
    for j=1:jmax-1
    u(i,j)=-(psi(i,j)-psi(i+1,j))/(y(i,j)-y(i+1,j));%[m^2s^-1]
    v(i,j)=+(psi(i,j)-psi(i,j+1))/(x(i,j)-x(i,j+1));
    end
end
end%if
u_ini=u;
v_ini=v;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
disp('start')

releasedSF6=0; %%%[l]

%%% release of the tracer alor a square spiral route
lagrangian_release_test_spiralrelease

%%% release of the same quantity of tracer (container [l]) 
%%% within a quadraticpatch
if vfield=='eddy';
    xc_eddy=xc_eddy_ini;
    yc_eddy=yc_eddy_ini;
end

lagrangian_release_test_quadraticpatch

%clear;
%close all;

%%% check total
%sum(sum(conc_spir,1))*dx*dy/conc_sat
%sum(sum(conc_quad,1))*dx*dy/conc_sat

container=container-releasedSF6

%%%%%%%%%%%%%%%%%%%%%%%%%%
%% PLOTS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%to center the final figures
x1=x-dx*fix(imax/2);
y1=y-dy*fix(jmax/2);
xp1_ini=xp_ini-dx*fix(imax/2);
yp1_ini=yp_ini-dy*fix(jmax/2);
xx1_ini=xx_ini-dx*fix(imax/2);
yy1_ini=yy_ini-dy*fix(jmax/2);

figure(1); hold on
%title('quadratic patch particles and initial spiral')
quiver(x1/1000,y1/1000,u_ini,v_ini);
%pcolor(x,y,conc_quad_ini);
plot(xp1_ini/1000,yp1_ini/1000,'g.')
plot(xx1_ini/1000,yy1_ini/1000,'r-');
%axis([0 xdistance 0 ydistance])
%axis([xc-4*coil_number*step_x xc+4*coil_number*step_x yc-4*coil_number*step_y yc+4*coil_number*step_y]);
axis([-10 10 -10 10])
xlabel('[km]');ylabel('[km]');
saveas(1,[figdir,'conc_eddy_ini.png'])


figure(2);hold on;
%title(['[SF6] of quadratic patch (colors) and spiral patch (lines) after
%',num2str(it*dt/3600,'%5.2f'),' [h]'])
%pcolor(x,y,conc_quad);colorbar;
contourf(x1/1000,y1/1000,conc_quad);shading flat;colorbar;
[C,h]=contour(x1/1000,y1/1000,conc_spir, 'k-');clabel(C,h);
%axis([-xdistance/2/1000 xdistance/2/1000 -ydistance/2/1000 ydistance/2/1000])
axis([-10 10 -10 10])
xlabel('[km]');ylabel('[km]');
colormap summer;
h = colorbar; set(get(h,'ylabel'),'string',['[',prefix_str,'Mol/l]'])
quiver(x1/1000,y1/1000,u,v);
saveas(2,[figdir,'conc_eddy_end.png'])

%figure(3)
%pcolor(x,y,conc_spir);colorbar;
%contourf(x,y,conc_spir);shading flat;colorbar;
%axis([0 dx*imax 0 dy*jmax])
%title('final concentrations of quadratic patch (colors) and spiral patch (lines)')

