%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% lagrangian_release_test.m (Matlab script)
%%
%% script to simulate a tracer release in an instantaneuous 
%% quadratic patch. 
%% Called by lagrangian_release_test.m
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli, F.Nencioli, M.Kersale
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%quadratic patch 
patch_res=2*coil_number*step_x/(round(sqrt(ipmax))-1);
ip=0;
for ix=xc-coil_number*step_x:patch_res:xc+coil_number*step_x
for iy=yc-coil_number*step_y:patch_res:yc+coil_number*step_y
ip=ip+1;
xp(ip)=ix;
yp(ip)=iy;
end
end

ipmax_quad=ip;
partweight_quad=releasedSF6*conc_sat/ipmax_quad;%[mol/particle]

xp_ini=xp;
yp_ini=yp;

%%% initial concentration
 conc_quad=zeros(jmax,imax);
for ip=1:ipmax_quad
 ii=fix(xp(ip)/dx);
 jj=fix(yp(ip)/dy);
 conc_quad(jj,ii)=conc_quad(jj,ii)+1;
end

conc_quad_ini=conc_quad;

%%%%%%%%%%%%%%%%%%
%%% TIME CYCLE %%%
%%%%%%%%%%%%%%%%%%
for it=1:itmax
    
 %%% MOVING EDDY WITH A DRIFT VELOCITY OF 5 cm/s    
if vfield=='eddy'
 xc_eddy=xc_eddy+vel_eddy*dt;
yc_eddy=yc_eddy;
psi = psimax*exp(-(((x-xc_eddy).^2)/2/sigma_eddy + ((y-yc_eddy).^2)/2/sigma_eddy));

 u(j,i)=0;
 v(j,i)=0.0;
 for i=1:imax-1
     for j=1:jmax-1
     u(i,j)=-(psi(i,j)-psi(i+1,j))/(y(i,j)-y(i+1,j));%[m^2s^-1]
     v(i,j)=+(psi(i,j)-psi(i,j+1))/(x(i,j)-x(i,j+1));
     end
 end   
end


%%%%%%%%%%%%%%%%%%%%%%
%%% PARTICLE CYCLE %%%
%%%%%%%%%%%%%%%%%%%%%%
for ip=1:ipmax_quad

 ii=fix(xp(ip)/dx);
 jj=fix(yp(ip)/dy);

 %%% advection
deltax=u(jj,ii)*dt;
deltay=v(jj,ii)*dt;

%%% random walk
  depx=randn*sigma;
  depy=randn*sigma;

  xpnew(ip)=xp(ip)+deltax+depx;
  ypnew(ip)=yp(ip)+deltay+depy;

   % bounday condition
  if xpnew(ip)<1*dx || xpnew(ip)>imax*dx || ypnew(ip)<1*dy || ypnew(ip)>jmax*dy
   xpnew(ip)=xp(ip);
   xpnew(ip)=yp(ip);
  end

 xp(ip)=xpnew(ip);
 yp(ip)=ypnew(ip);

 end%ip
 
 %Afin de n'afficher la figure que tous les 'deltatimes' pas de temps
if rem(it,deltatime)==0
  conc_quad=zeros(jmax,imax);
  %devst
  for ip=1:ipmax_quad
   %Calcule le nombre de particules dans chaque maille
   ii=fix(xp(ip)/dx);
   jj=fix(yp(ip)/dy);
   conc_quad(jj,ii)=conc_quad(jj,ii)+1;%[particles within a mesh]
  end
  conc_quad=conc_quad./dx./dy.*partweight_quad;%[mol/m²]
  conc_spir=conc_spir./dz;%[mol/m³]
  conc_spir=conc_spir./1000;%[mol/l]
  if detectiontreshold=='y';
      conc_spir(find(conc_spir<dec_treshold))=NaN;
  end
  conc_quad=conc_quad./prefix;
  
% figure(6);clf(6);hold on;
% title('concentrations of quadratic')
% %pcolor(x,y,conc_quad);colorbar;
% contourf(x,y,conc_quad);shading flat;colorbar;
% axis([0 dx*imax 0 dy*jmax])
% colormap summer;
% h = colorbar; set(get(h,'ylabel'),'string',['[',prefix_str,'Mol/m²]'])
% quiver(x,y,u,v)
% pause(0.1)


end%if rem


 
end%it

