%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% lagrangian_release_test.m (Matlab script)
%%
%% script to simulate a tracer release along a quadratic 
%% spiral route.
%% Called by lagrangian_release_test.m
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli, F.Nencioli, M.Kersale
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%
%%% TIME CYCLE %%%
%%%%%%%%%%%%%%%%%%
for it=1:itmax
it
    
%%% MOVING EDDY WITH A DRIFT VELOCITY OF 5 cm/s    
if vfield=='eddy';
xc_eddy=xc_eddy+vel_eddy*dt;
yc_eddy=yc_eddy;
psi = psimax*exp(-(((x-xc_eddy).^2)/2/sigma_eddy + ((y-yc_eddy).^2)/2/sigma_eddy));

 u(j,i)=0;
 v(j,i)=0.0;
 for i=1:imax-1
     for j=1:jmax-1
     u(i,j)=-(psi(i,j)-psi(i+1,j))/(y(i,j)-y(i+1,j));%[m^2s^-1]
     v(i,j)=+(psi(i,j)-psi(i,j+1))/(x(i,j)-x(i,j+1));
     end
 end
end

    
    
%%% reference buoy advection
ii=fix(xbuoy/dx);
jj=fix(ybuoy/dy);

deltax=u(jj,ii)*dt;
deltay=v(jj,ii)*dt;

xbuoynew=xbuoy+deltax;
ybuoynew=ybuoy+deltay;

xbuoy=xbuoynew;
ybuoy=ybuoynew;


%%% square spiral route
[coord_spiral,totdist]=spiral_calculation(coil_number,step_x,step_y);
if way=='in_out';
   xx=coord_spiral(1,:);
   yy=coord_spiral(2,:);
elseif way=='out_in';
   xx=coord_spiral(1,end:-1:1);
   yy=coord_spiral(2,end:-1:1);
else
   disp('ATTENTION! check the value of the parameter "way"')
end

%%% centered with respect reference buoy
xx=xx+xbuoy;
yy=yy+ybuoy;

if it==1
    xx_ini=xx;
    yy_ini=yy;
end



%%% calculation of particles release points along the route
[~,maxsize]=size(xx); 
xxnew(1)=xx(1);
yynew(1)=yy(1);
indice=2;

for i=2:maxsize
    if xx(i-1) ~= xx(i)
     distance=[max(xx(i-1),xx(i)) - min(xx(i-1),xx(i))];
     ipunti=round(distance/vel/dt);
     indicenew=indice+ipunti;
     if xx(i-1) > xx(i)
         xxnew(indice:indicenew)=[max(xx(i-1),xx(i)):-(distance/ipunti):min(xx(i-1),xx(i))];
     else
         xxnew(indice:indicenew)=[min(xx(i-1),xx(i)):(distance/ipunti):max(xx(i-1),xx(i))];
     end%if
     yynew(indice:indicenew)=yy(i-1);
    else
     distance=[max(yy(i-1),yy(i)) - min(yy(i-1),yy(i))];
     ipunti=round(distance/vel/dt);
     indicenew=indice+ipunti;
     if yy(i-1)>yy(i)
         yynew(indice:indicenew)=[max(yy(i-1),yy(i)):-(distance/ipunti):min(yy(i-1),yy(i))];
     else
         yynew(indice:indicenew)=[min(yy(i-1),yy(i)):(distance/ipunti):max(yy(i-1),yy(i))];
     end         
     xxnew(indice:indicenew)=xx(i-1);
    end%if
    indice=indicenew;
end%for


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%random walk with release along trajectory
[~,maxsize]=size(xxnew);
%shipdistanceKM=0;

    %shipdistanceKM=shipdistanceKM+vel*dt;
    %container=container-fluxSF6*dt%[l]
%disp(['TIME =',num2str(it*DT),'[h]'])
 
 if it<=maxsize;
     if releasedSF6 <= container;
     xold(it*flux-(flux-1):it*flux)=xxnew(it);
     yold(it*flux-(flux-1):it*flux)=yynew(it);
     %memoxxnew=xxnew(it);
     %memoyynew=yynew(it);
     %memoit=it;
 
     %%%plot of release
     if fig_spir=='y'
      if rem(it,it_fig_spir)==0
        figure(4);clf(4); hold on;
        quiver(x,y,u,v)
        plot(xold,yold,'g.')
        %%% route plotting
        plot(xbuoy,ybuoy,'bo')
        plot(xx,yy,'b-')
        plot(xxnew(1:it),yynew(1:it),'r-')
       hold off;
        %axis([0 dx*imax 0 dy*jmax])
        axis([xc-4*coil_number*step_x xc+4*coil_number*step_x yc-4*coil_number*step_y yc+4*coil_number*step_y]);
        %axis([xbuoy-2*coil_number*step_x xbuoy+2*coil_number*step_x ybuoy-2*coil_number*step_y ybuoy+2*coil_number*step_y]);
        title(['time =',num2str(it*dt/3600,'%5.2f'),...
               ' [h]   releasedSF6 =',num2str(releasedSF6,'%8.0f'), '[l]'])
        pause(0.1)
        
      end
     end%if fig_spir=='y'
     
          releasedSF6=releasedSF6+fluxSF6*dt; %%%[l]
          
      it_empty=it;
    end%if container
     
 end%it<=maxsize
 [~,ipmax]=size(xold);
 partweight_spir=releasedSF6*conc_sat/ipmax;%[mol/particle]

%%%%%%%%%%%%%%%%%%%%%%
%%% PARTICLE CYCLE %%%
%%%%%%%%%%%%%%%%%%%%%%
for ip=1:ipmax

ii=fix(xold(ip)/dx);
jj=fix(yold(ip)/dy);

%%% advection
deltax=u(jj,ii)*dt;
deltay=v(jj,ii)*dt;

%%% random walk
  depx=randn*sigma;
  depy=randn*sigma;
  
  X(ip)=xold(ip)+deltax+depx;
  Y(ip)=yold(ip)+deltay+depy;
  
  % bounday condition
  if X(ip)<=1*dx || X(ip)>=imax*dx || Y(ip)<=1*dy || Y(ip)>=jmax*dy
   X(ip)=xold(ip);
   Y(ip)=yold(ip);
  end

  xold(ip)=X(ip);
  yold(ip)=Y(ip);

 end%for ip
 
  

%Afin de n'afficher la figure que tous les 'deltatimes' pas de temps
if rem(it,deltatime)==0
  conc_spir=zeros(jmax,imax);
  %devst
  for ip=1:ipmax
   %Calcule le nombre de particules dans chaque maille
   ii=fix(X(ip)/dx);
   jj=fix(Y(ip)/dy);
   conc_spir(jj,ii)=conc_spir(jj,ii)+1;%[particles within a mesh]
  end
  conc_spir=conc_spir./dx./dy.*partweight_spir;%[mol/m²]
  if detectiontreshold=='y';
  conc_spir(find(conc_spir<0.2*10^-15))=NaN;
  end
  conc_spir=conc_spir./prefix;
  
% figure(7);clf(7);hold on;
% title('concentrations of spiral patch')
% contourf(x,y,conc_spir);shading flat;colorbar;
% axis([0 dx*imax 0 dy*jmax])
% colormap summer;
% h = colorbar; set(get(h,'ylabel'),'string','[nanoMol/m²]')
% quiver(x,y,u,v)
% pause(0.1)


  
end%if rem

end%it

%save memo_spir conc_spir

