%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Helps to plot the LATEX spiral of SF6 sampling 
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Petrenko, A.Doglioli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help lagrangian_sampling_spiral
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear; close all;

LATEXtools_param

%%
%=============%
%- VARIABLES -%
%=============%----------------------------------%
%- You have to change these variables to obtain -%
%- different spiral configurations.             -%
%------------------------------------------------%

%- Spiral parameters -%
ext_xlon =  35. ; % km 
ratio    =  1.6; % ratio between X and Y dimensions
maxdist  = 140. ; % [nm]
rotangle =  20. ; % degree N anticlockwise

dataplot = 'buoy';
%dataplot = 'adcp';
%dataplot = ' ';

%- buoy file name -%
%fname_latex='Positions_0711';
%m1 =    9; 
%d1 =   11;
%y1 = 2008;

%%
%==========================================================%
%- Change things below this line if you know what you do -%
%==========================================================%

%%
%============%
%- Constants-%
%============%

%- paths -%
dirout='./';

%- User coast in dirin -%
UserCoast='GOL.mat'; 

%- area limits -% (in degres)
lon_min =  2.8;
lon_max = 4.5;
lat_min = 41.6;
lat_max = 42.9;

%- Geographic projection for m_map -%
projection = 'mercator';
%AD: tested different projection: no sensitivity
%projection = 'lambert';
%projection = 'ortho';
%projection = 'sinusoidal';

pasX = 1; %minimal DX[km]
near = 1; %interval around choosen center [km]

%- Figures Identifiers -%
fid1 = figure('Visible','off');
fid2 = figure('Visible','off');
%NG: fid3 = figure('Visible','off');

%%
%====================================%
%- script to plot buoy or adcp data -%
%====================================%

%- Open figure -%
figure(fid1); 

subplot(1,4,[1 2 3]);

hold on;

%- M_map projection and representation of the coast -%
m_proj(projection,'lon',[lon_min lon_max],'lat',[lat_min lat_max]);
m_grid('box','fancy','tickdir','in');
if exist(UserCoast,'file')
  m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
else
  m_coast('patch',[0.7 0.7 0.7],'edgecolor','k');
end
%% SPANISH WATERS LIMITS
m_plot([3.1 3.5 3.5],[42.5 42.5 lat_min],'r-')
m_text(3.4,41.9,'\bf Spanish waters','color','r','Rotation',90)

%%- call the routine selected by "dataplot" to plot the data -%
if strcmp(dataplot,'buoy')
     %- plot buoys positions on figure fid1 -%
        %map_ArgosFloats

        next_lon_Iridium=  3.7577; %3.7711
        next_lat_Iridium= 42.6318; %42.6097
        
        next_lon= 3.6791; % 3.7000
        next_lat=42.2459; %42.2500

%         m_plot(next_lon_Iridium,next_lat_Iridium,'ro')
%         m_text(next_lon_Iridium,next_lat_Iridium+0.03,[' IRIDIUM prevu pour 20:00GMT � ',datestr(now,'HH:MM'),'GMT'])
%         m_plot(next_lon,next_lat,'b*')
%         m_text(next_lon,next_lat-0.03,[' 83631 prevu pour 20:00GMT � ',datestr(now,'HH:MM'),'GMT'])
        
elseif strcmp(dataplot,'adcp')
    %- plot adcp measurements on figure fid1 -%
    plot_ADCP_center; 
end

%- resize the figure window -%
figure(fid1);
scrsz = get(0,'ScreenSize');
set(fid1,'Position',[scrsz(3)/8 scrsz(4)/4 scrsz(3)/1.5 scrsz(4)/1.5]); 

%- Add title, labels and text -%
title(['LATEX Sampling Spiral #3'],...
       'FontWeight','bold','FontSize',14);
xlabel('Longitude', 'FontWeight','bold','FontSize',14);
ylabel('Latitude' , 'FontWeight','bold','FontSize',14);
	
mtid = m_text(3.3,43.2,...
     'Choose the spiral center by the mouse',...
     'Color','r','FontWeight','bold','FontSize',14);

%%
%==================================================%
%- Matlab function to position interactively with -%
%- the mouse the center of the spiral             -%
%==================================================%
waitfor(msgbox('Please, choose the center of the sampling spiral','start'));
[xc,yc] = ginput(1); %[windows coordinates]
%[xc,yc] = m_ll2xy(3.7167,42.4015);%% exemple for a given position
%%
%====================================================%
%- Compute the spiral centered on xc,yc coordinates -%
%====================================================%

    %%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Andrea OLD method %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%
%     %- Infiny value to maximize while loop -%
%     totdistanceKM2 = Inf('double');
%     pasX = 1.; %minimal DX[km]
%     DpasX = 1.; %increment [km]
%     near = 1.; %interval around choosen center [km]
%     
%     while totdistanceKM2 >= maxdist * 1.852;
%         
%         [totdistanceKM,xx,yy] = funct_sampling(pasX,ext_xlon,maxdist,ratio,near); %[km]
%         
%         totdistanceKM2 = totdistanceKM; %[km]
%         
%         pasX = pasX + DpasX; %[km]
%         
%     end
     
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %%% Francesco NEW method %%%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%  
    totdistanceKM2 = 0;
    pasX = 1; %minimal DX[km]
    near = 1; %interval around choosen center [km]
    
    xn=1;
    while totdistanceKM2 <= maxdist * 1.852;
        
	    pasX=ext_xlon/(2*xn);
	    pasY=(ext_xlon*ratio)/(2*xn);
        %[totdistanceKM,xx,yy] = spiral_calculation(xn,pasX,pasY); %[km]
        [coord_spiral,totdistanceKM] = spiral_calculation(xn,pasX,pasY); %[km]

        totdistanceKM2 = totdistanceKM; %[km]
        
        xn= xn + 1; %[km]
    end
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%
%============%
%- Rotation -%
%============%
    %[tt,rr]=cart2pol(xx,yy);
    [tt,rr]=cart2pol(coord_spiral(1,:),coord_spiral(2,:));
    [xx,yy]=pol2cart(tt+rotangle*pi/180,rr);
%%
%=====================================================%
%- Open a second figure to represent only the spiral -%
%=====================================================%
% figure(fid2); 
% hold on;
% 
% %---------------------------%
% %- plot the spriral center -%
% %---------------------------%
% plot(xc,yc,'*');
% 
% %-------------------%
% %- plot the spiral -%
% %-------------------%
% plot(xx,yy,'o-');

%---------------------------------------------%
%-  convertion to lon lat, see help m_lldist -%
%---------------------------------------------%
[trah,mysize] = size(xx);
[lonc,latc]   = m_xy2ll(xc,yc);

%---------------------------------------------%
%- Convertion from cartesian coordinates to polar -%
%---------------------------------------------%
[theta,ds] = cart2pol((xx-xc),(yy-yc));
a12        = 90-theta*180/pi;           %azimuth[degree with respect N]
ds         = ds*1000;                   %distance [m]

%-----------------------%
%- Calculate distances -%
%-----------------------%
%  [lonspir,latspir,a21] = m_fdist(lonc,latc,a12(1:mysize),s,'clrk66')
%  [lonspir,latspir,a21] = m_fdist(lonc,latc,a12(1:mysize),s,'sphere')
[lonspir,latspir,a21] = m_fdist(lonc,latc,a12,ds,'grs80');
%AD: no sensitivity to differents projections

%AD: CHECK DISTANCES
m_lldist(lonspir,latspir);
%figure(fid3);hold on; plot([lonspir],[latspir],'b*-');

%%
%===================================%
%- Plot Spiral on the first figure -%
%===================================%
figure(fid1);

set(mtid,'Visible','off');

hold on;

m_plot(lonc,latc,'k*');

m_plot(lonspir,latspir,'k-');

 totdistanceNM=totdistanceKM/1.852;
    
lonr = lon_max+(lon_max-lon_min)/10;
latr = lat_max;
skip=(latr -lat_min)/15;
m_text(lonr,latr,['\bf{totdistanceNM: ',num2str(totdistanceNM),' [nm]}']);
m_text(lonr,latr-skip,['\bf{ext-xlon: '     ,num2str(ext_xlon),' [km]}']);
m_text(lonr,latr-2*skip,['\bf{ratio: '        ,num2str(ratio),' [ ]}']);
m_text(lonr,latr-3*skip,['\bf{rotangle: '     ,num2str(rotangle),' [deg]}']);
m_text(lonr,latr-4*skip,'\bf{Spiral lon - lat: [deg]}');

[trash,irmax]=size(lonspir);

for ir=1:irmax
    m_text(lonr+.1, latr-.45 - ((ir-1) * 0.05),...
        [num2str(ir),': ',num2str(lonspir(ir)),...
        ' - ', num2str(latspir(ir))]);
    m_text(lonspir(ir), latspir(ir), num2str(ir),...
        'Color','r','BackgroundColor',[.7 .9 .7],...
        'FontSize',8);
end


%m_plot([next_lon_Iridium next_lon lonspir(1)],[next_lat_Iridium next_lat latspir(1)],'k--')
%        m_plot(next_lon_Iridium,next_lat_Iridium,'ro')
%        m_text(next_lon_Iridium,next_lat_Iridium+0.04,[' IRIDIUM prevu pour 22:00LT � ',datestr(now,'HH:MM'),'GMT'],'BackgroundColor','w')
%        m_text(next_lon_Iridium,next_lat_Iridium+0.04,[' IRIDIUM prevu pour 22:00LT'],'BackgroundColor','w')
%        m_plot(next_lon,next_lat,'b*')
%        m_text(next_lon,next_lat-0.04,[' 83631 prevu pour 22:00LT � ',datestr(now,'HH:MM'),'GMT'],'BackgroundColor','w')
%        m_text(next_lon,next_lat-0.04,[' 83631 prevu pour 22:00LT'],'BackgroundColor','w')



%%
%==============================%
%- Save results in ASCII file -%
%==============================%
% %- open the file with write permission -%
% 
% fid = fopen('SamplingSpiralLatLon.txt','w');
% 
% for ir=1:irmax
% fprintf(fid, '%12.4f %12.4f\r\n', [lonspir(ir) latspir(ir)]);
% end
% 
% edit SamplingSpiralLatLon.txt
% 
% fclose(fid);

%%
%==================================%
%- Print figures in graphic files -%
%==================================%
orient landscape;
fig_fn=strcat(...
    'spriral_',...
    num2str(totdistanceKM),'_',...
    num2str(ext_xlon),'_',...
    num2str(ratio),'_',...
    num2str(rotangle),'.tif');

%- Figure Printing -%
print(1,'./figures/SamplingSpiral.png','-dpng','-r200');
%
disp(' ');
disp('----- END ---')
