%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw vessel routes
%%%
%%% INPUT : 
%%%
%%% OUTPUT: m_map figure, stations ASCII file, route ASCII file
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% 22/09/2010 : andrea.doglioli@univmed.fr : compatibility with other
%%%              tools
%%% 17/09/2010 : francesco.nencioli@univmed.fr
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help make_route
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
LATEXtools_param
%%
% load the position file
fname='tethys_stations.txt';
%
%- Date of FSLE map -%
year=2010;
month=9;
day=22;
%
%- FSLE Caption position
lon_text=4;
lat_text=42.2;
%
%- Map boundaries -%
lonmin=3;
lonmax=5;
latmin=42;
latmax=43.9;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure
figure(1); hold on; 
m_proj(projection,'lon',[lonmin lonmax],'lat',[latmin latmax])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY(dirin_BATHY,[200 500]);

%- FSLE map
% unstable FSLE manifold
m_line([3.6 3.6 3.75],[latmin 42.666 latmax],'color','r','linewidth',2)

plot_FSLE(dirin_FSLE,year,month,day,lon_text,lat_text)

%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% plot stations
positions=load([dirin_Log_Position,fname]);
l_pos=length(positions(:,1));
%lon=decimal_position(positions(:,5),positions(:,6),positions(:,7));
%lat=decimal_position(positions(:,2),positions(:,3),positions(:,4));
lon=positions(:,7);
lat=positions(:,6);
num=positions(:,1);

% remove clustered stations around T18
bad=[1 21 22 23 24 26 27 28 29 30 31 36 37 10 2 42 43 44 45];
for i=length(bad):-1:1
	lon(num==bad(i))=[];
	lat(num==bad(i))=[];
	num(num==bad(i))=[];
end

m_plot(lon,lat,'k*')
for i=1:length(num)
	m_text(lon(i)+0.02,lat(i),['T',num2str(num(i))])
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5

% acquire new points
e=input('Do you wanna start from an existing position? [y/n]','s');
if e=='y'
	a='n';

	while a=='n'
		ns=input(['Choose a station number [',num2str(positions(1,1)),' ',num2str(positions(end,1)),']:']);
		if ns<=positions(end,1) & ns>=positions(1,1)
			xx=find(positions(:,1)==ns);
			NUM=ns;
			%LON=decimal_position(positions(xx,5),positions(xx,6),positions(xx,7));
			%LAT=decimal_position(positions(xx,2),positions(xx,3),positions(xx,4));
			LON=positions(xx,7);
			LAT=positions(xx,6);
		else
			error('Wrong station number')
		end
		disp(['The starting point is lon=',num2str(LON),', lat=',num2str(LAT)])
		a=input('Do you wanna keep it: [y/n]','s');
		if a=='n'
			disp('')
		elseif a=='y'
			m_plot(LON,LAT,'r*');
			m_text(LON+0.02,LAT,['T',num2str(NUM)],'color','r')
			prev_pos=[LON LAT];
		end
    end%while

elseif e=='n'
	disp('Click on the map to select the first point')
	a='c';
	while a=='c'
		[X Y]=ginput(1);
		[LON LAT]=m_xy2ll(X,Y);
		disp(['The selected point is lon=',num2str(LON),', lat=',num2str(LAT)])
		a=input('Do you wanna keep it, edit, or choose again: [k/e/c]','s');
		if a=='c'
			disp('Choose again')
		elseif a=='k'
			NUM=length(positions(:,1));
			m_plot(LON,LAT,'r*');
			m_text(LON+0.02,LAT,['T',num2str(NUM)],'color','r')
		elseif a=='e'
			lon_deg=input('Enter lon degree: ');
			lon_min=input('Enter lon minutes: ');
			lat_deg=input('Enter lat degree: ');
			lat_min=input('Enter lat minutes: ');
			LON=degmin_to_decideg(lon_deg,lon_min);
			LAT=degmin_to_decideg(lat_deg,lat_min);
			NUM=length(positions(:,1));
			m_plot(LON,LAT,'r*');
			m_text(LON+0.02,LAT,['T',num2str(NUM)],'color','r')
        end%if
    end%while
	[deg_lat, min_lat,hemi]=decideg_to_degmin(LAT,'lat');
	[deg_lon, min_lon,hemi]=decideg_to_degmin(LON,'lon');
	positions=([positions; [NUM deg_lat min_lat deg_lon min_lon LAT LON]]);
end%if

[deg_lat, min_lat,hemi]=decideg_to_degmin(LAT,'lat');
[deg_lon, min_lon,hemi]=decideg_to_degmin(LON,'lon');
new_pos=([NUM deg_lat min_lat 0 deg_lon min_lon 0]);
prev_pos=[LON LAT];

e='y';
b='y';
while b=='y'
	e=input('Do you wanna choose an existing location? [y/n]','s');
	if e=='y'
		a='n';
		while a=='n'
			ns=input(['Choose a station number [',num2str(positions(1,1)),' ',num2str(positions(end,1)),']:']);
			if ns<=positions(end,1) & ns>=positions(1,1)
				xx=find(positions(:,1)==ns);
				%LON=decimal_position(positions(xx,5),positions(xx,6),positions(xx,7));
				%LAT=decimal_position(positions(xx,2),positions(xx,3),positions(xx,4));
				LON=positions(xx,7);
				LAT=positions(xx,6);
			else
				error('Wrong station number')
			end
			disp(['The new point is lon=',num2str(LON),', lat=',num2str(LAT)])
			a=input('Do you wanna keep it: [y/n]','s');
			if a=='n'
				disp('')
			elseif a=='y'
				NUM=ns;
				m_plot(LON,LAT,'r*');
				m_text(LON+0.02,LAT,['T',num2str(NUM)],'color','r')
				m_line([prev_pos(1) LON],[prev_pos(2) LAT],'color','r')
			end
		end

	elseif e=='n'

		a='c';
		disp('Click on the map again to select the point')
		while a=='c'
			[X Y]=ginput(1);
			[LON LAT]=m_xy2ll(X,Y);
			disp(['The selected point is lon=',num2str(LON),', lat=',num2str(LAT)])
			a=input('Do you wanna keep it, edit, or choose again: [k/e/c]','s');
			if a=='c'
				disp('Choose again')
			elseif a=='k'
				NUM=length(positions(:,1));
				m_plot(LON,LAT,'r*');
				m_text(LON+0.02,LAT,['T',num2str(NUM)],'color','r')
				m_line([prev_pos(1) LON],[prev_pos(2) LAT],'color','r')
			elseif a=='e'
				lon_deg=input('Enter lon degree: ');
				lon_min=input('Enter lon minutes: ');
				lat_deg=input('Enter lat degree: ');
				lat_min=input('Enter lat minutes: ');
				LON=degmin_to_decideg(lon_deg,lon_min);
				LAT=degmin_to_decideg(lat_deg,lat_min);
				NUM=length(positions(:,1));
				m_plot(LON,LAT,'r*');
				m_text(LON+0.02,LAT,['T',num2str(NUM)],'color','r')
				m_line([prev_pos(1) LON],[prev_pos(2) LAT],'color','r')
			end
		end
		e=='y';
		[deg_lat, min_lat,hemi]=decideg_to_degmin(LAT,'lat');
		[deg_lon, min_lon,hemi]=decideg_to_degmin(LON,'lon');
		%positions=[positions; [NUM deg_lat min_lat 0 deg_lon min_lon 0 LON LAT]];
		positions=[positions; [NUM deg_lat min_lat deg_lon min_lon LAT LON]];
	end
	[deg_lat, min_lat,hemi]=decideg_to_degmin(LAT,'lat');
	[deg_lon, min_lon,hemi]=decideg_to_degmin(LON,'lon');
	new_pos=([new_pos;[NUM deg_lat min_lat 0 deg_lon min_lon 0]]);
	prev_pos=[LON LAT];

	b=input('Do you wanna select another point? [y/n]','s');
end
%new_pos=positions(l_pos:end,:);

new_pos_lon=degminsec_to_decideg(new_pos(:,5),new_pos(:,6),new_pos(:,7));
new_pos_lat=degminsec_to_decideg(new_pos(:,2),new_pos(:,3),new_pos(:,4));
new_dist=m_lldist(new_pos_lon,new_pos_lat);

new_dist_nm=new_dist./1.852;
vel=8; % knots=nm/hour
time=new_dist_nm./vel;
new_dist=[0;new_dist];
new_dist_nm=[0;new_dist_nm];
time=[0;time];

total_time=cumsum(time);
total_new_dist=cumsum(new_dist);
total_new_dist_nm=cumsum(new_dist_nm);

new_pos=[new_pos,new_dist,new_dist_nm,time,total_new_dist,total_new_dist_nm,total_time];
new_var=positions(l_pos+1:end,:);

% output the variables

a=input('Do you wanna save the current track? [y/n]','s');
if a=='y'
    path_out=figdir;
    
	fname_out=['tethys_track_',datestr(now,'yyyymmddTHHMM'),'.txt'];
	
    [fname_out,dir_out]=uiputfile([path_out,fname_out],'Save created track');
	
    fid=fopen([dir_out,fname_out],'w');
	fprintf(fid,'%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n','%#','Lat','Min','Sec','Lon','Min','Sec','Dist','D.(nm)','t','Cum.D.','C.D(nm)','Cum.t');
	for i=1:length(new_pos(:,1))
		fprintf(fid,'%.0f\t%.0f\t%.0f\t%.0f\t%.0f\t%.0f\t%.0f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\t%.3f\n',new_pos(i,:));
	end
	fclose(fid);
    edit([dir_out,fname_out]) 

    if length(new_var(:,1))>0
        %save in a temporary ASCII file
        fname=[fname(1:end-3),'tmp']
        fid=fopen([path_in,fname],'w');
        for i=1:length(new_var(:,1))
            %fprintf(fid,'%.0f\t\t%.0f\t%.0f\t%.0f\t\t%.0f\t%.0f\t%.0f\t%.4f\t\t%.4f\n',new_var(i,:));
            fprintf(fid,'%.0f\t%.0f\t%.2f\t%.0f\t%.2f\t%.4f\t%.4f\n',new_var(i,:));
        end
        fclose(fid);
        edit([path_in,fname]) 
    end%if lenght

    %print figure
	fig_out=['fig_tethys_track_',datestr(now,'yyyymmddTHHMM')];
	[fig_out,dir_out_fig]=uiputfile([path_out,fig_out],'Save track map');
	print([dir_out_fig,fig_out],'-dpng','-r200')

else
    disp('Track not saved')
end

%
disp(' ');
disp('----- END ---')

