%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with ARGOS buoys trajecotries
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure of FSLE manifolds and buoys trajectories
%%%
%%% ALGORITHM: calcuate de projection,
%%%            plot the trajectories and
%%%            print the figure
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli, F.Nencioli, L.Rousselet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_ARGOS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
LATEXtools_param
%
%- Buoy identifiers' list -%
buoylist=[48863 48903 48920 48939 48940]; 
%
%- Time interval of the trajectories -%
interval=[datenum(2010,9,20,0,0,0) now];
interval1=[datenum(2010,9,21,10,0,0) now];
interval2=[datenum(2010,9,21,9,0,0) now];
interval3=[datenum(2010,9,21,10,0,0) now];
%
%- Map boundaries -%
lonmin=3;
lonmax=4.3;
latmin=42;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure -%
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Loop plotting trajectories with same options
for buoy_id=buoylist
    plot_ARGOS(dirin_ARGOS,buoy_id,'ro',interval);
end
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-ARGOS'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY('BATHYMETRY_NWMED/',[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,[figdir,'map_ARGOS.png'],'-dpng','-r200');
%
disp(' ');
disp('----- END ---')
