%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Script for draw a geographical map with FSLE manifolds
%%
%% INPUT : coastline .mat file
%%
%% OUTPUT: m_map figure 
%%
%% ALGORITHM: calcuate de projection and
%%            plot
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: F.Nencioli, A.Doglioli, L.Rousselet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_FSLE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
LATEXtools_param
%
%- Date of FSLE map
year=2010;
month=9;
day=4;
%
%- Caption position
lon_text=4;
lat_text=42.2;
%
%- Map boundaries -%
lonmin=3;
lonmax=4.3;
latmin=42;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax])
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
% plot the manifolds
plot_FSLE(dirin_FSLE,year,month,day,lon_text,lat_text)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-FSLE'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY(dirin_BATHY,[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,[figdir,'map_FSLE.png'],'-dpng','-r200');
%
disp(' ');
disp('----- END ---')
