%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with colored
%%% circles of SF6 concentration
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure of SF6 concentration
%%%         if pplottype=1 plot a contour
%%%         else plot a coloured dot at the sampling station
%%%
%%% ALGORITHM: calcuate de projection and plot
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli, L.Rousselet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_SF6
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
LATEXtools_param
%
plottype=1;
%plottype=2;
%
%mapping_id='2';
mapping_id='3';
%
%- area limits -% (in degres)
lon_min = 3;%min(lonSF6)-0.1;
lon_max = 4;
lat_min = 42.3;
lat_max = 42.8;
%
%- Geographip projection for m_map -%
projection = 'mercator';
%%% FIGURE
figure(1);hold on
m_proj(projection,'lon',[lon_min lon_max],'lat',[lat_min lat_max]);

plot_SF6(dirin_SF6,mapping_id,plottype);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-SF6'])
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY(dirin_BATHY,[200 500]);
%
%- User's High Resolution Coastline -%
UserCoast='GOL.mat';
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,[figdir,'map_SF6_mapping',mapping_id,'_',num2str(plottype),'.png'],'-dpng','-r200');
%
disp(' ');
disp('----- END ---')
