%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Script for draw a geographical map with vessel trajecotries
%%%
%%% INPUT : coastline .mat file
%%%
%%% OUTPUT: m_map figure of vessel trajectories
%%%
%%% ALGORITHM: calcuate de projection and
%%%            plot the vessel trajecotries
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli, F.Nencioli, L.Rousselet
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
help map_VESSEL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
clear;close all;
%%
LATEXtools_param
%
vessel_name='tethys'; %%% file 
%
%- Time interval of the trajectories -%
interval=[datenum(2010,9,1,0,0,0) datenum(2010,9,20,0,0,0)];
%
%- 
myopt='b';
%
%- Map boundaries -%
lonmin=3;
lonmax=10;
latmin=42;
latmax=43.2;
%
%- Geographic projection for m_map -%
projection = 'mercator';
%
%- User coast in dirin -%
UserCoast='GOL.mat'; % in "sub_functions" directory
%
%- Plot the figure -%
figure(1); hold on; 
m_proj('mercator','lon',[lonmin lonmax],'lat',[latmin latmax]);
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
plot_VESSEL(dirin_VESSEL,interval,vessel_name,myopt);
%
%%% stations
% m_plot(3.9333,42.667,'r*');
% m_text(3.9333,42.667,' T60');
% m_range_ring(3.9333,42.667,2*1.852,'Color','r');
% 
% m_plot(4.3,42.9,'b*');
% m_text(4.3,42.9,' T61');
% m_range_ring(4.3,42.9,2*1.852,'Color','r');
% 
% m_plot(4.047,42.736,'c*');
% m_text(4.047,42.736,'. T62');
% m_range_ring(4.047,42.736,2*1.852,'Color','r')
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%- Figure title -%
title(['LATEX 2010 map-VESSEL']);
%
%- NW Mediterranean High Resolution Isobaths -%
plot_BATHY(dirin_BATHY,[200 500]);
%
%- User's High Resolution Coastline -%
m_usercoast(UserCoast,'patch',[.7 .7 .7],'edgecolor','k');
%m_coast('patch',[.7 .7 .7],'edgecolor','k');
%
%- Geographical Axis -%
m_grid('box','fancy','tickdir','in');
xlabel('Longtitude');
ylabel('Latitude');
%
%- Figure Printing -%
print(1,[figdir,'map_VESSEL.png'],'-dpng','-r200');
%
disp(' ');
disp('----- END ---')
