%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% function [time,lon,lat,u,v]=plot_ADCP(dirin,fname,interval,mydepth,...
%%                                       myopt,myscale,legend_unit,legend_lon,legend_lat)
%%
%% Plots the current vector from ADCP data
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: Z.Hu, A.Doglioli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [time,lon,lat,u,v]=plot_ADCP(dirin,fname,interval,mydepth,...
                                      myopt,myscale,legend_unit,legend_lon,legend_lat)

load([dirin,fname]);

final_analyser
final_updated_file

indexes=find(time>=interval(1) & time<=interval(2)); 

indexz=find(depth==mydepth);
while isempty(indexz)==1
    disp('The chosen depth is not available!');
    disp('Please, choose one of the following available depths :');
    disp(num2str(depth'));
    mydepth=input(': ');
    indexz=find(depth==mydepth);
end

lon=lon(indexes);
lat=lat(indexes);
time=time(indexes);%[days]
u=u(indexz,indexes);
v=v(indexz,indexes);

%%% to have a scaled vector with respect the legend
u=u.*myscale;
v=v.*myscale;

m_quiver(lon,lat,u,v,myscale);

m_text(lon(1),lat(1),datestr(time(1),'dd/mm HH:MM'),...
       'Color','k','FontWeight','bold','BackgroundColor','w','HorizontalAlignment','Left');
m_text(lon(end),lat(end),datestr(time(end),'dd/mm HH:MM'),...
       'Color','k','FontWeight','bold','BackgroundColor','w','HorizontalAlignment','Left');

add_my_arrow(legend_lon,legend_lat,legend_unit,myscale,'[ms^{-1}]','r');

m_text(legend_lon,legend_lat-legend_lat/1000*3,['Depth=',num2str(mydepth),'[m]'],...
       'Color','r');

return
