%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% script for plotting data of the SF6 concentration
%%%
%%% INPUT : ASCII file sf6_mapping_vessel_coord_nb*_VStethys.txt
%%%
%%% OUTPUT: add to a m_map figure of SF6 concentration
%%%
%%% ALGORITHM: loads the data 
%%%         if pplottype=1 plot a contour
%%%         else plot a coloured dot at the sampling station
%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: Y.Leredde, A.Doglioli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [timeSF6,lonSF6,latSF6,concSF6]=plot_SF6(dirin,mapping_id,plottype)


%load function
[timeSF6,lonSF6,latSF6,concSF6]=load_SF6(dirin,mapping_id);

   
if(plottype==1)
    
%plot a contour map
    F=TriScatteredInterp(lonSF6,latSF6,concSF6,'natural');
    [lonSF6interp,latSF6interp]=meshgrid([3:0.01:4],[41.5:0.01:43]);
    concSF6interp=F(lonSF6interp,latSF6interp);
    
    m_contourf(lonSF6interp,latSF6interp,concSF6interp);
    colorbar;
    hold on;
    m_plot(lonSF6,latSF6,'wx')
    
else

%plot a circle at (lonSF6,latSF6) with a color depending to concSF6
scale=7;
couleur=colormap;
n=length(concSF6);
mc=min(concSF6);
mac=max(concSF6);
tp11c=1+fix((concSF6-mc)*length(couleur)/(mac-mc));
for i=1:n
    if(concSF6(i)<mc)
        tp11c(i)=1;
    end
    if(concSF6(i)>=mac)
        tp11c(i)=63;
    end
end
for i=1:n  
    if(isnan(concSF6(i))==0)
       m_plot(lonSF6(i),latSF6(i),'o','MarkerEdgeColor',couleur(tp11c(i),:),...
        'MarkerFaceColor',couleur(tp11c(i),:),'markersize',5);  
    end%if
    %m_text(lonSF6(i),latSF6(i),datestr(timeSF6(i),'HH:MM'))
    caxis([0 mac])
    colorbar

    title(datestr(timeSF6(i)))


end%if(plottype~='dots')
%pause(0.01)
end %i
