%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% spiral_calculation.m (Matlab script)
%% 
%% Computes a spiral with a number of corners defined by coil_number,
%% and a longitudinal and latitudinal spacing defined by step_x and step_y respectively;
%%
%% There are a number of user defined switches that can be set to change
%% the sense and type of rotation of the spiral.
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%% Credits : F.Nencioli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [coord_spiral,totdist]=spiral_calculation(coil_number,step_x,step_y)
%---------------------------
% User defined parameters: %
%---------------------------
% 1) Center of the spiral
acoord(1)=0;
bcoord(1)=0;
% 2) direction of the first step:
% the first step from the origin can be set to be 
% along y ('y') or along x ('x')
first_step='x';
% 3) sense of direction of the first 2 steps:
% - switch1 determines if the first step is towards positive (1) or negative (-1) direction
% - switch2 determines if the second step is towards positive (1) or negative (-1) direction
% (The rest of the spiral is computed iteratively)
switch1=-1;
switch2=1;
%================================================================

if first_step=='x'
	stepa=step_x;
	stepb=step_y;
elseif first_step=='y'
	stepa=step_y;
	stepb=step_x;
else
	error('First_step can only be ''x'' or ''y'' ')
end

if abs(switch1)~=1 || abs(switch2)~=1
	error('switch1 or switch2 can only be +1 or -1')
end

% Start to iterativelly compute the spiral vertices.
% For each loop there are four points that are computed 
% until the number of loops reach the maximum defined by nombre_de_creneaux
for i=1:coil_number
	% compute position of first corner of the loop
	acoord((4*i)+1-3)=acoord(((4*i)+1-3)-1)+(switch1*stepa*(i*2-1));
	bcoord((4*i)+1-3)=bcoord(((4*i)+1-3)-1);
	switch1=-switch1;
	% compute position of second corner of the loop
	acoord((4*i)+1-2)=acoord((4*i)+1-3);
	bcoord((4*i)+1-2)=bcoord((4*i)+1-3)+(switch2*stepb*(i*2-1));
	switch2=-switch2;
	% compute position of third corner of the loop
	acoord((4*i)+1-1)=acoord((4*i)+1-2)+(switch1*stepa*(i*2));
	bcoord((4*i)+1-1)=bcoord((4*i)+1-2);
	switch1=-switch1;
	% compute position of fourth corner of the loop
	acoord((4*i)+1)=acoord((4*i)+1-1);
	bcoord((4*i)+1)=bcoord((4*i)+1-1)+(switch2*stepb*(i*2));
	switch2=-switch2;
end
% acoord and bcoord are saved as xcoord or ycoord depending on the values of first_step
if first_step=='x'
	coord_spiral=[acoord;bcoord];
elseif first_step=='y'
	coord_spiral=[bcoord;acoord];
end

% enleve le point central (bouee) de la spirale
coord_spiral=coord_spiral(:,2:end);




%[totdist,xx,yy]
%if first_step=='x'
	%xx=acoord;
	%yy=bcoord;
%elseif first_step=='y'
	%xx=bcoord;
	%yy=acoord;
%end
% compute tot dist
i=1:coil_number*2;
totdist=sum((stepa+stepb)*i);


return

