%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%                    LATEXtools                         %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  This  file  is  free software ;  it  is distributed  in  %
%%  the hope that  it  will  be  useful,  but  without  any  %
%%  warranty.  You  can  redistribute  it and/or modify  it  %
%%  under  the  terms  of  the  GNU  General Public License  %
%%  as  published  by  the   Free  Software  Foundation  at  %
%%       http://www.gnu.org/copyleft/gpl.html                %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% vortex.m (Matlab script)
%%
%% Calculates Cartesian component of current velocity for
%% a circular eddy.
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% 28/05/13 : andrea.doglioli@univ-amu.fr : first official release
%%
%% Credits: A.Doglioli
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [XX,YY,uu,vv]=vortex(sense,xmin,xmax,ymin,ymax,numx,numy)

%%%%%%%%%%%%%   Define the spatial grid

% xmin = -3;     %   Minimum value of x
% xmax = +3;     %   Maximum value of x
% ymin = -3;     %   Minimum value of y
% ymax = +3;     %   Maximum value of y
% numx = 100;     %   Number of points in x direction
% numy = 100;     %   Number of points in y direction

dx = (xmax-xmin)/(numx-1);   %  Step in x direction
dy = (ymax-ymin)/(numy-1);   %  Step in y direction

x = linspace(xmin,xmax,numx);   %  Vector of x values
y = linspace(ymin,ymax,numy);   %  Vector of y values

[XX,YY] = meshgrid(x,y);  %  2D arrays of x and y on grid.

THETA = atan2(YY,XX);   %   Azimuthal angle

RR = sqrt(XX.*XX+YY.*YY);  % Radial distance r.
VV = (sech(RR).^2).*tanh(RR);  % Azimuthal speed.

if     sense=='cycl'
    uu = - VV.*sin(THETA);  %  x component of velocity
    vv = + VV.*cos(THETA);  %  y component of velocity
elseif sense=='anti'
    uu = + VV.*sin(THETA);  %  x component of velocity
    vv = - VV.*cos(THETA);  %  y component of velocity
else
    disp('sense: ERROR');
end    

